@@ -8,7 +8,7 @@ from senor_octopus.graph import Source
 _logger = logging.getLogger(__name__)
 
 
-SLEEP_TIME = 1
+SLEEP_TIME = 5
 
 
 class Scheduler:
@@ -18,10 +18,10 @@ class Scheduler:
     async def run(self) -> None:
         nodes = {node for node in self.dag if node.schedule}
         if not nodes:
-            _logger.info("Nothing to schedule...")
+            _logger.info("Nothing to schedule")
             return
 
-        _logger.info("Starting scheduler...")
+        _logger.info("Starting scheduler")
         loop = asyncio.get_event_loop()
 
         schedules: Dict[str, float] = {}
@@ -32,12 +32,12 @@ class Scheduler:
                 when = now + delay
 
                 if node.name not in schedules:
-                    _logger.info(f"Scheduling {node.name} to run in {delay} seconds...")
+                    _logger.info(f"Scheduling {node.name} to run in {delay} seconds")
                     schedules[node.name] = when
                 elif schedules[node.name] <= now:
-                    _logger.info(f"Running {node.name}...")
+                    _logger.info(f"Running {node.name}")
                     await node.run()
                     del schedules[node.name]
 
-            _logger.debug(f"Sleeping for {SLEEP_TIME} seconds...")
+            _logger.debug(f"Sleeping for {SLEEP_TIME} seconds")
             await asyncio.sleep(SLEEP_TIME)
